pub enum Error {
Io(Error),
Confy(ConfyError),
Sqlite(Error),
Fmt(Error),
Storage,
TwoTimer(TimeError),
TimeNotSupported,
TimeSpanNotSupported,
InvalidUnicode(OsString),
NoDirectory(String),
NoParentDirectory,
}Expand description
Mrot error variants
Variants
Io(Error)
wraps std::io::Error
Confy(ConfyError)
wraps confy::ConfyError
Sqlite(Error)
wraps sqlite::Error
Fmt(Error)
wraps std::fmt::Error
Storage
when something could not be stored in the storage
TwoTimer(TimeError)
wraps two_timer::TimeError
TimeNotSupported
when a chrono::NaiveDate cannot be converted to chrono::NaiveDateTime
TimeSpanNotSupported
if the user input a time span instead of time
InvalidUnicode(OsString)
when OsString does not contain valid Unicode
NoDirectory(String)
when directories::ProjectDirs is not found
NoParentDirectory
when a path does not have a parent directory